@@ -49,10 +49,11 @@ void tobase64(unsigned char *buf) {
     strcpy(buf, bof);
 }
 
-int start_http(int s,unsigned char options,char *miscptr,FILE *fp) {
+int start_http(int s, int port, unsigned char options,char *miscptr,FILE *fp) {
     char *empty = "";
     char *login, *pass, buffer[300], buffer2[110];
     char *header = "";  // XXX TODO:
+    char *ptr;
 
     if (strlen(login = hydra_get_next_login()) == 0) login = empty;
     if (strlen(pass = hydra_get_next_password()) == 0) pass = empty;
@@ -60,7 +61,7 @@ int start_http(int s,unsigned char options,char *miscptr,FILE *fp) {
     sprintf(buffer2, "%.50s:%.50s", login, pass);
     tobase64(buffer2);
 
-    sprintf(buffer, "HEAD %.250s HTTP/1.0\nAuthorization: Basic %s\nUser-Agent: Mozilla/4.0\n%s\n",
+    sprintf(buffer, "HEAD %.250s HTTP/1.0\r\nAuthorization: Basic %s\r\nUser-Agent: Mozilla/4.0 (Hydra)\r\n%s\r\n",
         miscptr, buffer2, header);
 
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
@@ -79,12 +80,16 @@ int start_http(int s,unsigned char options,char *miscptr,FILE *fp) {
 //        recv(s, buffer, sizeof(buf), 0);
 ////        buf = hydra_receive_line(s);
 
-    if ((char) *(index(buf, ' ') + 1) == '2')
-        hydra_report_found(fp);
-    else if ((char) *(index(buf, ' ') + 1) != '4')
-        printf("Unusual return code: %c for %s:%s\n", (char) *(index(buf, ' ') + 1), login,pass);
+    ptr = ((char*)index(buf, ' ')) + 1;
+    if (*ptr == '2') {
+        hydra_report_found(port, "www", fp);
+        hydra_completed_pair_found();
+    } else {
+        if (*ptr != '4')
+            printf("Unusual return code: %c for %s:%s\n", (char) *(index(buf, ' ') + 1), login,pass);
+        hydra_completed_pair();
+    }
 
-    hydra_completed_pair();
     free(buf);
 
     if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
@@ -94,10 +99,10 @@ int start_http(int s,unsigned char options,char *miscptr,FILE *fp) {
 }
 
 void service_http(unsigned long int ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
-    int run = 1, next_run, sock = -1, myport = 80;
+    int run = 1, next_run, sock = -1;
+    int myport = PORT_HTTP, mysslport = PORT_HTTP_SSL;
 
     hydra_register_socket(sp);
-    if (port != 0) myport = port;
     if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
         return;
     while(1) {
@@ -107,15 +112,24 @@ void service_http(unsigned long int ip, int sp, unsigned char options, char *mis
                    {
                     if (sock >= 0) sock = hydra_disconnect(sock);
                     usleep(275000);
-                    if ((sock = hydra_connect_tcp(ip, myport)) < 0) {
-                        fprintf(stderr, "Error: Child with pid %d terminating, can not connect\n", getpid());
+                    if ((options & OPTION_SSL) == 0) {
+                        if (port != 0) myport = port;
+                        sock = hydra_connect_tcp(ip, myport);
+			port = myport;
+                    } else {
+                        if (port != 0) mysslport = port;
+                        sock = hydra_connect_ssl(ip, mysslport);
+			port = mysslport;
+                    }
+                    if (sock < 0) {
+                        fprintf(stderr, "Error: Child with pid %d terminating, can not connect\n", (int)getpid());
                         hydra_child_exit();
                     }
                     next_run = 2;
                     break;
                    }
             case 2: /* run the cracking function */
-                    next_run = start_http(sock, options, miscptr, fp);
+                    next_run = start_http(sock, port, options, miscptr, fp);
                     break;
             case 3: /* clean exit */
                     if (sock >= 0) sock = hydra_disconnect(sock);
